Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code | Sign in
(252)

Unified Diff: src/stats/model/time-probe.h

Issue 245260043: DCF collectors
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Please Sign in to add in-line comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/stats/model/time-probe.h
===================================================================
--- a/src/stats/model/time-probe.h
+++ b/src/stats/model/time-probe.h
@@ -39,7 +39,7 @@
*
* This class is designed to probe an underlying ns3 TraceSource exporting
* an ns3::Time. This probe exports a trace source "Output" of type
* double, in units of seconds. The Output trace source emits a value when
* either the trace source emits a new value, or when SetValue () is called.
*
* The current value of the probe can be polled with the GetValue ()
@@ -57,9 +57,9 @@
virtual ~TimeProbe ();
/**
- * \return the most recent value (units of seconds)
+ * \return the most recent value
*/
- double GetValue (void) const;
+ Time GetValue (void) const;
/**
* \param value set the traced Time to a new value
@@ -102,7 +102,7 @@
*/
void TraceSink (Time oldData, Time newData);
- TracedValue<double> m_output; //!< Output trace source.
+ TracedValue<Time> m_output; //!< Output trace source.
};
} // namespace ns3
@@ -39,7 +39,7 @@
* This class is designed to probe an underlying ns3 TraceSource exporting
* an ns3::Time. This probe exports a trace source "Output" of type
- * double, in units of seconds. The Output trace source emits a value when
+ * Time. The Output trace source emits a value when
* either the trace source emits a new value, or when SetValue () is called.
*

Powered by Google App Engine
RSS Feeds Recent Issues | This issue
This is Rietveld f62528b